pub fn parse_gemfile(content: &str, doc_uri: &Uri) -> Result<BundlerParseResult>Expand description
Parses a Gemfile and extracts all dependencies with positions.
pub fn parse_gemfile(content: &str, doc_uri: &Uri) -> Result<BundlerParseResult>Parses a Gemfile and extracts all dependencies with positions.